@@ -14,7 +14,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_args_from_argv);
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 our %SPEC;
 
@@ -317,10 +317,20 @@ sub get_args_from_argv {
             # parse argv_aliases
             if ($as->{cmdline_aliases}) {
                 while (my ($al, $alspec) = each %{$as->{cmdline_aliases}}) {
-                    $go_opt = $name2go_opt->(
-                        $al, $alspec->{schema} // $as->{schema});
+                    my $type =
+                        $alspec->{schema} ? $alspec->{schema}[0] :
+                            $as->{schema} ? $as->{schema}[0] : '';
+                    if ($alspec->{code} && $type eq 'bool') {
+                        # bool --alias doesn't get --noalias if has code
+                        $go_opt = $al; # instead of "$al!"
+                    } else {
+                        $go_opt = $name2go_opt->(
+                            $al, $alspec->{schema} // $as->{schema});
+                    }
+
                     if ($alspec->{code}) {
-                        push @go_spec, $go_opt=>sub {$alspec->{code}->($args)};
+                        push @go_spec,
+                            $go_opt=>sub {$alspec->{code}->($args, $_[1])};
                     } else {
                         push @go_spec, $go_opt=>$go_handler;
                     }
@@ -446,7 +456,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
